@@ -1,6 +1,9 @@
 from genomics.burrows import *
 from genomics.global_alignment import *
+import csv
 import logging
+import time
+
 
 logger = logging.getLogger(__name__)
 
@@ -14,6 +17,15 @@ def get_seed(seed_length, read):
     return read[0: seed_length]
 
 
+def generate_scoring_points(match, mismatch, gap):
+    return {
+        'M': match,
+        'Ti': mismatch,
+        'Tv': mismatch,
+        'G': gap
+    }
+
+
 # make coarse then do fine refine
 def seed_and_extend(scoring_points, references, reads, margin=3, seed_length=10, reference_index=0):
 
@@ -27,6 +39,27 @@ def seed_and_extend(scoring_points, references, reads, margin=3, seed_length=10,
     occ_matrix, tots = make_occurrences_matrix(bwt_reference)
     c = first_col(tots)
     suff_arr = make_suffix_array(reference)
+
+    matches = [0, 1, 2]
+    mismatches = [-3, -2]
+    gaps = [-7, -5]
+    for match in matches:
+        for mismatch in mismatches:
+            for gap in gaps:
+                scoring_points = generate_scoring_points(match, mismatch, gap)
+                file_out = handle_reads(reads, seed_length, c, margin, occ_matrix, reference, scoring_points, suff_arr)
+                write_results_to_csv_file2(f'results-{time.time()}-match-{match}-mismatch{mismatch}-gap{gap}.csv', file_out)
+
+
+def write_results_to_csv_file2(file_name, results):
+    with open(file_name, mode='w') as result_file:
+        writer = csv.writer(result_file)
+        writer.writerow(['start', 'end', 'alignment-score', 'transcription'])
+        for result in results:
+            writer.writerow(list(result))
+
+
+def handle_reads(reads, seed_length, c, margin, occ_matrix, reference, scoring_points, suff_arr):
     result = []
     for read in reads:
         # for each read extract substrins - seeds and reverse complement
